@@ -1,5 +1,8 @@
 #!/usr/bin/env bash
 
+# verbose
+#set -x
+
 set -o pipefail
 shopt -s failglob
 set -u
@@ -683,7 +686,7 @@ if [ "$STEAM_RUNTIME" -a "$STEAM_RUNTIME" != "0" ]; then
 		fi
 		export STEAM_RUNTIME_LIBRARY_PATH="$("$STEAM_RUNTIME/run.sh" --print-steam-runtime-library-paths)"
 
-		export LD_LIBRARY_PATH="$STEAM_RUNTIME_LIBRARY_PATH:${LD_LIBRARY_PATH-}"
+		export LD_LIBRARY_PATH="$STEAM_RUNTIME_LIBRARY_PATH"
 	else
 		echo "Unpack runtime failed, error code $?"
 		show_message --error $"Couldn't set up the Steam Runtime. Are you running low on disk space?\nContinuing..."
@@ -734,8 +737,24 @@ if [ "$STEAM_DEBUGGER" == "gdb" ] || [ "$STEAM_DEBUGGER" == "cgdb" ]; then
 		unset LD_PRELOAD
 	fi
 
-	echo $STEAM_DEBUGGER -x "$ARGSFILE" --args "$STEAMROOT/$STEAMEXEPATH" "$@"
-	$STEAM_DEBUGGER -x "$ARGSFILE" --args "$STEAMROOT/$STEAMEXEPATH" "$@"
+	# Ditto with LD_LIBRARY_PATH, avoids this below:
+	# gdb: /home/plagman/src/valve/Steam/main/client/ubuntu12_32/steam-runtime/pinned_libs_64/libcurl.so.4: version `CURL_OPENSSL_4' not found (required by /usr/lib/libdebuginfod.so.1)
+	: "${LD_LIBRARY_PATH=}"
+	if [ "$LD_LIBRARY_PATH" ]; then
+		echo set env LD_LIBRARY_PATH=$LD_LIBRARY_PATH >> "$ARGSFILE"
+		echo show env LD_LIBRARY_PATH >> "$ARGSFILE"
+		unset LD_LIBRARY_PATH
+	fi
+
+	# Enable index file caching for reasonable launch time under gdb
+	echo set index-cache on >> "$ARGSFILE"
+	echo show index-cache >> "$ARGSFILE"
+
+	: "${DEBUGGER_ARGS=}"
+	echo "gdb/cgdb launch with ARGSFILE: $ARGSFILE"
+	echo $STEAM_DEBUGGER -x "$ARGSFILE" $DEBUGGER_ARGS --args "$STEAMROOT/$STEAMEXEPATH" "$@"
+
+	$STEAM_DEBUGGER -x "$ARGSFILE" $DEBUGGER_ARGS --args "$STEAMROOT/$STEAMEXEPATH" "$@"
 	rm "$ARGSFILE"
 elif [ "$STEAM_DEBUGGER" == "valgrind" ]; then
 	: "${STEAM_VALGRIND:=}"
@@ -745,6 +764,8 @@ elif [ "$STEAM_DEBUGGER" == "callgrind" ]; then
 elif [ "$STEAM_DEBUGGER" == "strace" ]; then
 	strace -osteam.strace "$STEAMROOT/$STEAMEXEPATH" "$@"
 else
+	# Most likely not what you want!
+	echo "WARNING: Using default/fallback debugger launch"
 	echo $STEAM_DEBUGGER "$STEAMROOT/$STEAMEXEPATH" "$@"
 	$STEAM_DEBUGGER "$STEAMROOT/$STEAMEXEPATH" "$@"
 fi
